@@ -4,7 +4,9 @@ from __future__ import absolute_import
 import sys
 import threading
 import weakref
+from importlib import import_module
 
+from sentry_sdk._compat import string_types
 from sentry_sdk._types import TYPE_CHECKING
 from sentry_sdk.consts import OP, SPANDATA
 from sentry_sdk.hub import Hub, _should_send_default_pii
@@ -32,11 +34,17 @@ try:
     from django import VERSION as DJANGO_VERSION
     from django.conf import settings as django_settings
     from django.core import signals
+    from django.conf import settings
 
     try:
         from django.urls import resolve
     except ImportError:
         from django.core.urlresolvers import resolve
+
+    try:
+        from django.urls import Resolver404
+    except ImportError:
+        from django.core.urlresolvers import Resolver404
 except ImportError:
     raise DidNotEnable("Django not installed")
 
@@ -370,6 +378,18 @@ def _set_transaction_name_and_source(scope, transaction_style, request):
             transaction_name,
             source=source,
         )
+    except Resolver404:
+        urlconf = import_module(settings.ROOT_URLCONF)
+        # This exception only gets thrown when transaction_style is `function_name`
+        # So we don't check here what style is configured
+        if hasattr(urlconf, "handler404"):
+            handler = urlconf.handler404
+            if isinstance(handler, string_types):
+                scope.transaction = handler
+            else:
+                scope.transaction = transaction_from_function(
+                    getattr(handler, "view_class", handler)
+                )
     except Exception:
         pass
 
@@ -592,7 +612,7 @@ def install_sql_hook():
         with record_sql_queries(
             hub, self.cursor, sql, params, paramstyle="format", executemany=False
         ) as span:
-            _set_db_system_on_span(span, self.db.vendor)
+            _set_db_data(span, self.db.vendor, self.db.get_connection_params())
             return real_execute(self, sql, params)
 
     def executemany(self, sql, param_list):
@@ -604,7 +624,7 @@ def install_sql_hook():
         with record_sql_queries(
             hub, self.cursor, sql, param_list, paramstyle="format", executemany=True
         ) as span:
-            _set_db_system_on_span(span, self.db.vendor)
+            _set_db_data(span, self.db.vendor, self.db.get_connection_params())
             return real_executemany(self, sql, param_list)
 
     def connect(self):
@@ -617,7 +637,7 @@ def install_sql_hook():
             hub.add_breadcrumb(message="connect", category="query")
 
         with hub.start_span(op=OP.DB, description="connect") as span:
-            _set_db_system_on_span(span, self.vendor)
+            _set_db_data(span, self.vendor, self.get_connection_params())
             return real_connect(self)
 
     CursorWrapper.execute = execute
@@ -626,8 +646,22 @@ def install_sql_hook():
     ignore_logger("django.db.backends")
 
 
-# https://github.com/django/django/blob/6a0dc2176f4ebf907e124d433411e52bba39a28e/django/db/backends/base/base.py#L29
-# Avaliable in Django 1.8+
-def _set_db_system_on_span(span, vendor):
-    # type: (Span, str) -> None
+def _set_db_data(span, vendor, connection_params):
+    # type: (Span, str, Dict[str, str]) -> None
     span.set_data(SPANDATA.DB_SYSTEM, vendor)
+
+    db_name = connection_params.get("dbname") or connection_params.get("database")
+    if db_name is not None:
+        span.set_data(SPANDATA.DB_NAME, db_name)
+
+    server_address = connection_params.get("host")
+    if server_address is not None:
+        span.set_data(SPANDATA.SERVER_ADDRESS, server_address)
+
+    server_port = connection_params.get("port")
+    if server_port is not None:
+        span.set_data(SPANDATA.SERVER_PORT, server_port)
+
+    server_socket_address = connection_params.get("unix_socket")
+    if server_socket_address is not None:
+        span.set_data(SPANDATA.SERVER_SOCKET_ADDRESS, server_socket_address)
